from .anilistpy import *
from anilistpy.anime import Anime
from anilistpy.manga import Manga
from anilistpy.char import Character
from anilistpy.staff import Staff
from anilistpy.studio import Studio

from anilistpy.sr_manga import mangaSearch
from anilistpy.sr_anime import animeSearch
from anilistpy.sr_char import charSearch
from anilistpy.sr_staff import searchStaff
from anilistpy.sr_studio import searchStudio
from anilistpy.utils import videoLink

from anilistpy.mt_media import Media
from anilistpy.mt_user import User

from anilistpy.usr_medialist import MediaList 

'''
    easy to use wrapper for anilist apiv2
    Copyright (C) 2020  0kalekale

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as
    published by the Free Software Foundation, either version 3 of the
    License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program.  If not, see <https://www.gnu.org/licenses/>.
'''
